diff --git a/cli/mmcli-modem-simple.c b/cli/mmcli-modem-simple.c
index b09cd0fae5b9aff6195ea6ae371414a443b80d57..4efa77cd9d3b947e33cfa2ce4a23556d9ea7bece 100644
--- a/cli/mmcli-modem-simple.c
+++ b/cli/mmcli-modem-simple.c
@@ -210,9 +210,9 @@ get_modem_ready (GObject      *source,
 
         g_debug ("Asynchronously connecting the modem...");
 
-        /* Setup operation timeout: 2 minutes (to match MM internal timeout) */
-        g_dbus_proxy_set_default_timeout (G_DBUS_PROXY (ctx->modem_simple), 2 * 60 * 1000);
-
+        /* Setup operation timeout: 2 minutes 2 seconds (to match MM internal
+         * timeout with a bit of slack) */
+        g_dbus_proxy_set_default_timeout (G_DBUS_PROXY (ctx->modem_simple), ((2 * 60) + 2) * 1000);
         properties = mm_simple_connect_properties_new_from_string (connect_str, &error);
         if (!properties) {
             g_printerr ("Error parsing connect string: '%s'\n", error->message);
diff --git a/src/mm-broadband-modem.c b/src/mm-broadband-modem.c
index cd031e4c99e062b90c6ff6a3a5e4c623208ae0ca..ee2165250fe75c0b3d4150409788107030117e20 100644
--- a/src/mm-broadband-modem.c
+++ b/src/mm-broadband-modem.c
@@ -5317,7 +5317,7 @@ modem_3gpp_scan_networks (MMIfaceModem3gpp *self,
 {
     mm_base_modem_at_command (MM_BASE_MODEM (self),
                               "+COPS=?",
-                              300,
+                              315,
                               FALSE,
                               callback,
                               user_data);
diff --git a/cli/mmcli-modem-3gpp.c b/cli/mmcli-modem-3gpp.c
index dc34456728d9f831e32f042702693c5f0968fbcd..010f4c8bc17f1daab56888a6beaa6eaa02763b1b 100644
--- a/cli/mmcli-modem-3gpp.c
+++ b/cli/mmcli-modem-3gpp.c
@@ -551,8 +551,9 @@ get_modem_ready (GObject      *source,
     if (scan_flag) {
         g_debug ("Asynchronously scanning for networks...");
 
-        /* Setup operation timeout: 5 minutes (to match MM internal timeout) */
-        g_dbus_proxy_set_default_timeout (G_DBUS_PROXY (ctx->modem_3gpp), 5 * 60 * 1000);
+        /* Setup operation timeout: 5 minutes 17 seconds (to match MM internal
+         * timeout with a bit of slack) */
+        g_dbus_proxy_set_default_timeout (G_DBUS_PROXY (ctx->modem_3gpp), ((5 * 60) + 17) * 1000);
         mm_modem_3gpp_scan (ctx->modem_3gpp,
                             ctx->cancellable,
                             (GAsyncReadyCallback)scan_ready,
@@ -564,8 +565,9 @@ get_modem_ready (GObject      *source,
     if (register_in_operator_str || register_home_flag) {
         g_debug ("Asynchronously registering the modem...");
 
-        /* Setup operation timeout: 2 minutes (to match MM internal timeout) */
-        g_dbus_proxy_set_default_timeout (G_DBUS_PROXY (ctx->modem_3gpp), 2 * 60 * 1000);
+        /* Setup operation timeout: 2 minutes 2 seconds (to match MM internal
+         * timeout with a bit of slack) */
+        g_dbus_proxy_set_default_timeout (G_DBUS_PROXY (ctx->modem_3gpp), ((2 * 60) + 2) * 1000);
         mm_modem_3gpp_register (ctx->modem_3gpp,
                                 (register_in_operator_str ? register_in_operator_str : ""),
                                 ctx->cancellable,